==> rail-0.1.tar.bz2: rail-0.1/rail-table-semi.el <==
;; -*- coding: iso-2022-8bit-ss2; -*-

(defvar rail-semi-codename-alist
  '(("Kaga-Ichinomiya"    . "$(B2C2l0l$N5\(B")
    ("Naka-Tsurugi"       . "$(BCfDaMh(B")
    ("Tsurugi"            . "$(BDaMh(B")
    ("Hinomiko"           . "$(BF|8f;R(B")
    ("Oyanagi"            . "$(B>.Lx(B")
    ("Inokuchi"           . "$(B0f8}(B")
    ("D-Dhji-A"             . "$(BF;K!;{(B")
    ("Sodani"             . "$(BA>C+(B")
    ("Shijima"            . "$(B;M==K|(B")
    ("Otomaru"            . "$(B254](B")
    ("Nukaj-Dtaku-mae-A"     . "$(B3[=;BpA0(B")
    ("Magae"              . "$(BGOBX(B")
    ("Nonoichi-K-Ddaimae-A"  . "$(BLn!9;T9)BgA0(B")
    ("Nonoichi"           . "$(BLn!9;T(B")
    ("Oshino"             . "$(B2!Ln(B")
    ("Shin-Nishikanazawa" . "$(B?7@>6bBt(B")
    ("Nishiizumi"         . "$(B@>@t(B")
    ("Nomachi"            . "$(BLnD.(B")
    ("Naoetsu"            . "$(BD>9>DE(B")
    ("Tanihama"           . "$(BC+IM(B")
    ("Arimagawa"          . "$(BM-4V@n(B")
    ("Nadachi"            . "$(BL>N)(B")
    ("Tsutsuishi"         . "$(BE{@P(B")
    ("N-D-A"                 . "$(BG=@8(B")
    ("Uramoto"            . "$(B1:K\(B")
    ("Kajiyashiki"        . "$(B3a20I_(B")
    ("Itoigawa"           . "$(B;e5{@n(B")
    ("-Dmi-A"                . "$(B@D3$(B")
    ("Oyashirazu"         . "$(B?FITCN(B")
    ("Ichiburi"           . "$(B;T?6(B")
    ("Ecch-D-Miyazaki-A"     . "$(B1[Cf5\:j(B")
    ("Tomari"             . "$(BGq(B")
    ("Ny-Dzen-A"             . "$(BF~A1(B")
    ("Nishi-Ny-Dzen-A"       . "$(B@>F~A1(B")
    ("Ikuji"              . "$(B@8CO(B")
    ("Kurobe"             . "$(B9uIt(B")
    ("Uozu"               . "$(B5{DE(B")
    ("Higashi-Namerikawa" . "$(BEl3j@n(B")
    ("Namerikawa"         . "$(B3j@n(B")
    ("Mizuhashi"          . "$(B?e66(B")
    ("Higashi-Toyama"     . "$(BElIY;3(B")
    ("Toyama"             . "$(BIY;3(B")
    ("Kureha"             . "$(B8b1)(B")
    ("Kosugi"             . "$(B>.?y(B")
    ("Ecch-D-Daimon-A"       . "$(B1[CfBgLg(B")
    ("Takaoka"            . "$(B9b2,(B")
    ("Nishi-Takaoka"      . "$(B@>9b2,(B")
    ("Fukuoka"            . "$(BJ!2,(B")
    ("Isurugi"            . "$(B@PF0(B")
    ("Kurikara"           . "$(B6fMx2@Me(B")
    ("Tsubata"            . "$(BDEH((B")
    ("Morimoto"           . "$(B?9K\(B")
    ("Higashi-Kanazawa"   . "$(BEl6bBt(B")
    ("Kanazawa"           . "$(B6bBt(B")
    ("Nishi-Kanazawa"     . "$(B@>6bBt(B")
    ("[JR]"               . "Nonoichi")
    ("Matt-D-A"              . "$(B>>G$(B")
    ("Kaga-Kasama"        . "$(B2C2l3^4V(B")
    ("Mikawa"             . "$(BH~@n(B")
    ("Komaiko"            . "$(B>.Iq;R(B")
    ("Terai"              . "$(B;{0f(B")
    ("Meih-D-A"              . "$(BL@Jv(B")
    ("Komatsu"            . "$(B>.>>(B")
    ("Tsuruga"            . "$(BFX2l(B")
    ("Shin-Hikida"        . "$(B?7I%ED(B")
    ("-Dmi-Shiotsu-A"        . "$(B6a9>1vDE(B")
    ("Yogo"               . "$(BM>8b(B")
    ("Kinomoto"           . "$(BLZ%NK\(B")
    ("Takatsuki"          . "$(B9b7n(B")
    ("Kawake"             . "$(B2OLS(B")
    ("Torahime"           . "$(B8WI1(B")
    ("Nagahama"           . "$(BD9IM(B")
    ("Tamura"             . "$(BEDB<(B")
    ("Sakata"             . "$(B:dED(B")
    ("T-Dky-A"              . "$(BEl5~(B")
    ("Shinbashi"          . "$(B?766(B")
    ("Shinagawa"          . "$(BIJ@n(B")
    ("Kawasaki"           . "$(B@n:j(B")
    ("Yokohama"           . "$(B2#IM(B")
    ("Totsuka"            . "$(B8MDM(B")
    ("-Dfuna-A"              . "$(BBgA%(B")
    ("Fujisawa"           . "$(BF#Bt(B")
    ("Tsujid-D-A"            . "$(@DT$(BF2(B")
    ("Chigasaki"          . "$(B3}%v:j(B")
    ("Hiratsuka"          . "$(BJ?DM(B")
    ("-Diso-A"               . "$(BBg0k(B")
    ("Ninomiya"           . "$(BFs5\(B")
    ("K-Dzu-A"               . "$(B9qI\DE(B")
    ("Kamonomiya"         . "$(B3{5\(B")
    ("Odawara"            . "$(B>.ED86(B")
    ("Hayakawa"           . "$(BAa@n(B")
    ("Nebukawa"           . "$(B:,I\@n(B")
    ("Manazuru"           . "$(B??Da(B")
    ("Yugawara"           . "$(BEr2O86(B")
    ("Atami"              . "$(BG.3$(B")
    ("Kan'nami"           . "$(BH!Fn(B")
    ("Mishima"            . "$(B;0Eg(B")
    ("Numazu"             . "$(B>BDE(B")
    ("Katahama"           . "$(BJRIM(B")
    ("Hara"               . "$(B86(B")
    ("Higashi-Tagonoura"  . "$(BElED;R%N1:(B")
    ("Yoshiwara"          . "$(B5H86(B")
    ("Fuji"               . "$(BIY;N(B")
    ("Fujikawa"           . "$(BIY;N@n(B")
    ("Shin-Kambara"       . "$(B?73w86(B")
    ("Kambara"            . "$(B3w86(B")
    ("Yui"                . "$(BM3Hf(B")
    ("Okitsu"             . "$(B6=DE(B")
    ("Shimizu"            . "$(B@6?e(B")
    ("Kusanagi"           . "$(BApFe(B")
    ("Shizuoka"           . "$(B@E2,(B")
    ("Abekawa"            . "$(B0BG\@n(B")
    ("Mochimune"          . "$(BMQ=!(B")
    ("Yaizu"              . "$(B>FDE(B")
    ("Nishi-Yaizu"        . "$(B@>>FDE(B")
    ("Fijieda"            . "$(BF#;^(B")
    ("Rokug-D-A"             . "$(BO;9g(B")
    ("Shimada"            . "$(BEgED(B")
    ("Kanaya"             . "$(B6bC+(B")
    ("Kikugawa"           . "$(B5F@n(B")
    ("Kakegawa"           . "$(B3]@n(B")
    ("Fukuroi"            . "$(BB^0f(B")
    ("Iwata"              . "$(BHXED(B")
    ("Toyodach-D-A"          . "$(BK-EDD.(B")
    ("Tenry-Dgawa-A"         . "$(BE7N5@n(B")
    ("Hamamatsu"          . "$(BIM>>(B")
    ("Takatsuka"          . "$(B9bDM(B")
    ("Maisaka"            . "$(BIq:e(B")
    ("Bentenjima"         . "$(BJ[E7Eg(B")
    ("Araimachi"          . "$(B?75oD.(B")
    ("Wasizu"             . "$(BOIDE(B")
    ("Shinjohara"         . "$(B?7=j86(B")
    ("Futagawa"           . "$(BFs2O(B")
    ("Toyohashi"          . "$(BK-66(B")
    ("Kanayama"           . "$(B6b;3(B")
    ("Ot-Dbashi-A"           . "$(BHxF,66(B")
    ("Nagoya"             . "$(BL>8E20(B")
    ("Gifu"               . "$(B4tIl(B")
    ("Samegai"            . "$(B@C%v0f(B")
    ("Maibara"            . "$(BJF86(B")
    ("Kusatsu"            . "$(BApDE(B")
    ("Yamashina"          . "$(B;32J(B")
    ("Ky-Dto-A"              . "$(B5~ET(B")
    ("-Dsaka-A"              . "$(BBg:e(B")
    ("K-Dbe-A"               . "$(B?@8M(B")
    ("Himi"               . "$(BI98+(B")
    ("Shimao"             . "$(BEgHx(B")
    ("Amaharashi"         . "$(B1+@2(B")
    ("Ecch-D-Kokubu-A"       . "$(B1[Cf9qJ,(B")
    ("Fushiki"            . "$(BIzLZ(B")
    ("N-Dmachi-A"            . "$(BG=D.(B")
    ("Ecch-D-Nakagawa-A"     . "$(B1[CfCf@n(B")
    ("Takaoka"            . "$(B9b2,(B")
    ("Saigata"            . "$(B:T3c(B")
    ("Kubiki"             . "$(B$/$S$-(B")
    ("-Dike-Ikoinomori-A"    . "$(BBgCS$$$3$$$N?9(B")
    ("Nishi--Dtsu-A"         . "$(B@>BgDE(B")))

(provide 'rail-semi)

==> rail-1.1.1.tar.bz2: rail-1.1.1/rail-table-semi.el <==
;; -*- coding: ctext; -*-

(defvar rail-semi-codename-alist
  '(("Kaga-Ichinomiya"    . "$(B2C2l0l$N5\(B")
    ("Naka-Tsurugi"       . "$(BCfDaMh(B")
    ("Tsurugi"            . "$(BDaMh(B")
    ("Hinomiko"           . "$(BF|8f;R(B")
    ("Oyanagi"            . "$(B>.Lx(B")
    ("Inokuchi"           . "$(B0f8}(B")
    ("D-Dhji"-A             . "$(BF;K!;{(B")
    ("Sodani"             . "$(BA>C+(B")
    ("Shijima"            . "$(B;M==K|(B")
    ("Otomaru"            . "$(B254](B")
    ("Nukaj-Dtaku-mae"-A     . "$(B3[=;BpA0(B")
    ("Magae"              . "$(BGOBX(B")
    ("Nonoichi-K-Ddaimae"-A  . "$(BLn!9;T9)BgA0(B")
    ("Nonoichi"           . "$(BLn!9;T(B")
    ("Oshino"             . "$(B2!Ln(B")
    ("Shin-Nishikanazawa" . "$(B?7@>6bBt(B")
    ("Nishiizumi"         . "$(B@>@t(B")
    ("Nomachi"            . "$(BLnD.(B")
    ("Naoetsu"            . "$(BD>9>DE(B")
    ("Tanihama"           . "$(BC+IM(B")
    ("Arimagawa"          . "$(BM-4V@n(B")
    ("Nadachi"            . "$(BL>N)(B")
    ("Tsutsuishi"         . "$(BE{@P(B")
    ("N-D"-A                 . "$(BG=@8(B")
    ("Uramoto"            . "$(B1:K\(B")
    ("Kajiyashiki"        . "$(B3a20I_(B")
    ("Itoigawa"           . "$(B;e5{@n(B")
    ("-Dmi"-A                . "$(B@D3$(B")
    ("Oyashirazu"         . "$(B?FITCN(B")
    ("Ichiburi"           . "$(B;T?6(B")
    ("Ecch-D-Miyazaki"-A     . "$(B1[Cf5\:j(B")
    ("Tomari"             . "$(BGq(B")
    ("Ny-Dzen"-A             . "$(BF~A1(B")
    ("Nishi-Ny-Dzen"-A       . "$(B@>F~A1(B")
    ("Ikuji"              . "$(B@8CO(B")
    ("Kurobe"             . "$(B9uIt(B")
    ("Uozu"               . "$(B5{DE(B")
    ("Higashi-Namerikawa" . "$(BEl3j@n(B")
    ("Namerikawa"         . "$(B3j@n(B")
    ("Mizuhashi"          . "$(B?e66(B")
    ("Higashi-Toyama"     . "$(BElIY;3(B")
    ("Toyama"             . "$(BIY;3(B")
    ("Kureha"             . "$(B8b1)(B")
    ("Kosugi"             . "$(B>.?y(B")
    ("Ecch-D-Daimon"-A       . "$(B1[CfBgLg(B")
    ("Nishi-Takaoka"      . "$(B@>9b2,(B")
    ("Fukuoka"            . "$(BJ!2,(B")
    ("Isurugi"            . "$(B@PF0(B")
    ("Kurikara"           . "$(B6fMx2@Me(B")
    ("Tsubata"            . "$(BDEH((B")
    ("Morimoto"           . "$(B?9K\(B")
    ("Higashi-Kanazawa"   . "$(BEl6bBt(B")
    ("Kanazawa"           . "$(B6bBt(B")
    ("Nishi-Kanazawa"     . "$(B@>6bBt(B")
    ("[JR] Nonoichi"      . "[JR] $(BLn!9;T(B")
    ("Matt-D"-A              . "$(B>>G$(B")
    ("Kaga-Kasama"        . "$(B2C2l3^4V(B")
    ("Mikawa"             . "$(BH~@n(B")
    ("Komaiko"            . "$(B>.Iq;R(B")
    ("Terai"              . "$(B;{0f(B")
    ("Meih-D"-A              . "$(BL@Jv(B")
    ("Komatsu"            . "$(B>.>>(B")
    ("Awazu"              . "$(B0@DE(B")
    ("Tsuruga"            . "$(BFX2l(B")
    ("Shin-Hikida"        . "$(B?7I%ED(B")
    ("-Dmi-Shiotsu"-A        . "$(B6a9>1vDE(B")
    ("Yogo"               . "$(BM>8b(B")
    ("Kinomoto"           . "$(BLZ%NK\(B")
    ("Takatsuki"          . "$(B9b7n(B")
    ("Kawake"             . "$(B2OLS(B")
    ("Torahime"           . "$(B8WI1(B")
    ("Nagahama"           . "$(BD9IM(B")
    ("Tamura"             . "$(BEDB<(B")
    ("Sakata"             . "$(B:dED(B")
    ("T-Dky"-A              . "$(BEl5~(B")
    ("Shinbashi"          . "$(B?766(B")
    ("Shinagawa"          . "$(BIJ@n(B")
    ("Kawasaki"           . "$(B@n:j(B")
    ("Yokohama"           . "$(B2#IM(B")
    ("Totsuka"            . "$(B8MDM(B")
    ("-Dfuna"-A              . "$(BBgA%(B")
    ("Fujisawa"           . "$(BF#Bt(B")
    ("Tsujid-D"-A            . "$(BDTF2(B")
    ("Chigasaki"          . "$(B3}%v:j(B")
    ("Hiratsuka"          . "$(BJ?DM(B")
    ("-Diso"-A               . "$(BBg0k(B")
    ("Ninomiya"           . "$(BFs5\(B")
    ("K-Dzu"-A               . "$(B9qI\DE(B")
    ("Kamonomiya"         . "$(B3{5\(B")
    ("Odawara"            . "$(B>.ED86(B")
    ("Hayakawa"           . "$(BAa@n(B")
    ("Nebukawa"           . "$(B:,I\@n(B")
    ("Manazuru"           . "$(B??Da(B")
    ("Yugawara"           . "$(BEr2O86(B")
    ("Atami"              . "$(BG.3$(B")
    ("Kan'nami"           . "$(BH!Fn(B")
    ("Mishima"            . "$(B;0Eg(B")
    ("Numazu"             . "$(B>BDE(B")
    ("Katahama"           . "$(BJRIM(B")
    ("Hara"               . "$(B86(B")
    ("Higashi-Tagonoura"  . "$(BElED;R%N1:(B")
    ("Yoshiwara"          . "$(B5H86(B")
    ("Fuji"               . "$(BIY;N(B")
    ("Fujikawa"           . "$(BIY;N@n(B")
    ("Shin-Kambara"       . "$(B?73w86(B")
    ("Kambara"            . "$(B3w86(B")
    ("Yui"                . "$(BM3Hf(B")
    ("Okitsu"             . "$(B6=DE(B")
    ("Shimizu"            . "$(B@6?e(B")
    ("Kusanagi"           . "$(BApFe(B")
    ("Shizuoka"           . "$(B@E2,(B")
    ("Abekawa"            . "$(B0BG\@n(B")
    ("Mochimune"          . "$(BMQ=!(B")
    ("Yaizu"              . "$(B>FDE(B")
    ("Nishi-Yaizu"        . "$(B@>>FDE(B")
    ("Fijieda"            . "$(BF#;^(B")
    ("Rokug-D"-A             . "$(BO;9g(B")
    ("Shimada"            . "$(BEgED(B")
    ("Kanaya"             . "$(B6bC+(B")
    ("Kikugawa"           . "$(B5F@n(B")
    ("Kakegawa"           . "$(B3]@n(B")
    ("Fukuroi"            . "$(BB^0f(B")
    ("Iwata"              . "$(BHXED(B")
    ("Toyodach-D"-A          . "$(BK-EDD.(B")
    ("Tenry-Dgawa"-A         . "$(BE7N5@n(B")
    ("Hamamatsu"          . "$(BIM>>(B")
    ("Takatsuka"          . "$(B9bDM(B")
    ("Maisaka"            . "$(BIq:e(B")
    ("Bentenjima"         . "$(BJ[E7Eg(B")
    ("Araimachi"          . "$(B?75oD.(B")
    ("Wasizu"             . "$(BOIDE(B")
    ("Shinjohara"         . "$(B?7=j86(B")
    ("Futagawa"           . "$(BFs2O(B")
    ("Toyohashi"          . "$(BK-66(B")
    ("Kanayama"           . "$(B6b;3(B")
    ("Ot-Dbashi"-A           . "$(BHxF,66(B")
    ("Nagoya"             . "$(BL>8E20(B")
    ("Gifu"               . "$(B4tIl(B")
    ("Samegai"            . "$(B@C%v0f(B")
    ("Maibara"            . "$(BJF86(B")
    ("Kusatsu"            . "$(BApDE(B")
    ("Yamashina"          . "$(B;32J(B")
    ("Ky-Dto"-A              . "$(B5~ET(B")
    ("-Dsaka"-A              . "$(BBg:e(B")
    ("K-Dbe"-A               . "$(B?@8M(B")
    ("Himi"               . "$(BI98+(B")
    ("Shimao"             . "$(BEgHx(B")
    ("Amaharashi"         . "$(B1+@2(B")
    ("Ecch-D-Kokubu"-A       . "$(B1[Cf9qJ,(B")
    ("Fushiki"            . "$(BIzLZ(B")
    ("N-Dmachi"-A            . "$(BG=D.(B")
    ("Ecch-D-Nakagawa"-A     . "$(B1[CfCf@n(B")
    ("Takaoka"            . "$(B9b2,(B")
    ("Saigata"            . "$(B:T3c(B")
    ("Kubiki"             . "$(B$/$S$-(B")
    ("-Dike-Ikoinomori"-A    . "$(BBgCS$$$3$$$N?9(B")
    ("Nishi--Dtsu"-A         . "$(B@>BgDE(B")))

(provide 'rail-table-semi)
